#include <SI_EFM8LB1_Register_Enums.h>                  // SFR declarations
#include "Project_DefsVarsFuncs.h"

bit LAST_SCAN = FALSE;

//this variable is used to reserve the memory used by the ADC autoscan hardware
unsigned char xdata AutoScan_Memory[3000]   _at_   0x000;

unsigned int AutoScan_StartingAddress = 0x000;	//in XRAM

void ConfigureADC_AutoScan(void)
{
	SFRPAGE = ADC0_PAGE;

	ADC0ASCF |= BIT6;	//one trigger will initiate the entire scan

	//configure the scan for three channels
	ADC0ASCF |= BIT1;
	ADC0ASCF &= ~BIT0;

	/*We need to write the starting address into the two
	 * relevant registers. It's a 12-bit address. The upper byte
	 * goes into ADC0ASAH, but note that the upper four bits of
	 * ADC0ASAH must be binary 0000, so just to be sure we clear
	 * the upper four bits of the high byte of AutoScan_StartingAddress
	 * before writing it to the register. Then we write the lower byte to
	 *  ADC0ASAL. The least significant bit of the address is ignored,
	 *  which means that the address must be an even number. The
	 *  least significant bit of ADC0ASAL is used not for addressing
	 *  but for choosing between little endian and big endian.*/
	ADC0ASAH = HIGHBYTE(0x0FFF & AutoScan_StartingAddress);
	ADC0ASAL = LOWBYTE(0xFFFE & AutoScan_StartingAddress);
	/*Note that we clear the LSbit of AutoScan_StartingAddress.
	 * This ensures that the LSbit of ADC0ASAL is always zero, and
	 * zero corresponds to big endian.*/

	ADC0ASCT = (SCAN_SIZE_BYTES_ACC/2) - 1;	//scan size = ADC0ASCT + 1

	ADC0ASCF |= BIT7;	//enable autoscan

	//now we need to load the address for the next scan
	AutoScan_StartingAddress = AutoScan_StartingAddress + SCAN_SIZE_BYTES_ACC;
	ADC0ASAH = HIGHBYTE(0x0FFF & AutoScan_StartingAddress);
	ADC0ASAL = LOWBYTE(0xFFFE & AutoScan_StartingAddress);
}
